package com.qzingtech.im;

import com.corundumstudio.socketio.Configuration;
import com.corundumstudio.socketio.SocketIOServer;
import com.corundumstudio.socketio.annotation.SpringAnnotationScanner;
import com.qzing.framework.core.repository.DefaultWiselyRepositoryImpl;
import com.qzing.framework.query.advance.jpa.JpaRepositoryFactoryBeanExt;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.cache.CacheManager;
import org.springframework.cache.annotation.EnableCaching;
import org.springframework.cache.ehcache.EhCacheCacheManager;
import org.springframework.cloud.client.discovery.EnableDiscoveryClient;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.FilterType;
import org.springframework.core.annotation.Order;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;

import java.util.concurrent.CompletableFuture;

@SpringBootApplication
@Order(1)
@Slf4j
@EnableDiscoveryClient
@EnableFeignClients(basePackages = {"com.qzing"})
@EnableJpaRepositories(basePackages = {"com.qzing","com.qzingtech"}, repositoryBaseClass = DefaultWiselyRepositoryImpl.class,
        repositoryFactoryBeanClass = JpaRepositoryFactoryBeanExt.class)
@EntityScan(basePackages = {"com.qzing","com.qzingtech"})
@ComponentScan(basePackages = {"com.qzing","com.qzingtech"},
        excludeFilters = @ComponentScan.Filter(type = FilterType.ASSIGNABLE_TYPE,
                value = {com.qzing.ieep.mvc.exception.GlobalExceptionHandler.class,
                        com.qzing.ieep.mvc.exception.GlobalErrorController.class
                        }))
public class IMApplication implements CommandLineRunner {

    private SocketIOServer server;
//    @Value("${screen.ip}")
//    private String screenIp;
    public static void main(String[] args) {
        SpringApplication.run(IMApplication.class, args);
    }

    @Bean
    public SocketIOServer socketIOServer() {
        Configuration config = new Configuration();
        config.setHostname("0.0.0.0");
        config.setPort(4553);
        this.server = new SocketIOServer(config);
        return server;
    }

    @Bean
    public SpringAnnotationScanner springAnnotationScanner(SocketIOServer socketServer) {
        return new SpringAnnotationScanner(socketServer);
    }

    @Override
    public void run(String... args) throws Exception {
        CompletableFuture.runAsync(() -> server.start());
//        server.start();sysParamServiceImpl
        log.info("socket.io run success!");
        // 向"channel_1" push数据
        // new IMService().send(args);
    }

}

