package com.qzingtech.im.handler;

import com.corundumstudio.socketio.AckRequest;
import com.corundumstudio.socketio.SocketIOClient;
import com.corundumstudio.socketio.SocketIOServer;
import com.corundumstudio.socketio.annotation.OnConnect;
import com.corundumstudio.socketio.annotation.OnDisconnect;
import com.corundumstudio.socketio.annotation.OnEvent;
import com.qzingtech.im.service.DashboardService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.UUID;

/**
 * 消息处理器
 *
 * @author kai.guo@qzingtech.com
 * @date 2019/12/26
 */
@Slf4j
@Component
public class MessageEventHandler implements ApplicationContextAware {

    public static SocketIOServer socketIoServer;

    @Autowired
    public MessageEventHandler(SocketIOServer server) {
        MessageEventHandler.socketIoServer = server;
    }

    private ApplicationContext applicationContext;

    private final static String CHANNEL_NAME = "timePerformanceGoodProduct";

    @Autowired
    private DashboardService dashboardService;



    @OnConnect
    public void onConnect(SocketIOClient client) {
        UUID socketSessionId = client.getSessionId();
        String ip = client.getRemoteAddress().toString();
        log.info("client connect, socketSessionId:{}, ip:{}", socketSessionId, ip);
        client.joinRoom(CHANNEL_NAME);

    }


    @OnEvent("timePerformanceGoodProduct")
    public void timePerformanceGoodProductOee(SocketIOClient client, AckRequest request, String channel, Map<String, Object> data) {
        String oneWeekOEE = dashboardService.getScreenTypeService(data);
        client.sendEvent(CHANNEL_NAME,oneWeekOEE);
        //sendEventEquipData("timePerformanceGoodProduct", oneWeekOEE);
    }

    @OnDisconnect
    public void onDisconnect(SocketIOClient client) {
        UUID socketSessionId = client.getSessionId();
        String ip = client.getRemoteAddress().toString();
        log.info("client disconnect, socketSessionId:{}, ip:{}", socketSessionId, ip);
//        dashboardService.removeMap(socketSessionId);
    }



    public static void sendEventData(UUID clientId,String eventName,String data) {
        socketIoServer.getClient(clientId).sendEvent(eventName,data);
    }


    public static void sendEventEquipData(String channel,String data) {
        socketIoServer.getRoomOperations(CHANNEL_NAME).sendEvent(channel, data);
        log.info(data);
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }
}